@@ -1,4 +1,5 @@
 from dataclasses import dataclass, field
+from typing import Optional
 
 import requests
 import pandas as pd
@@ -8,6 +9,7 @@ from llcsciencesdk.exceptions import (
     ApiGeneralError,
     ApiTokenError,
 )
+from llcsciencesdk.helpers import json_response_to_df
 from llcsciencesdk.urls import make_urls, ApiUrls
 
 
@@ -33,12 +35,12 @@ class ScienceSdk:
 
         self.auth_token = r.json()["access"]
 
-    def get_model_input(self, url, site_design_configuration_id: int):
+    def get_request(self, url, url_params: Optional[str] = ""):
         if not self.auth_token:
             raise ApiTokenError
 
         response = requests.get(
-            url + str(site_design_configuration_id),
+            url + str(url_params),
             headers={"Authorization": f"Bearer {self.auth_token}"},
         )
 
@@ -48,17 +50,17 @@ class ScienceSdk:
         self, site_design_configuration_id: int
     ) -> dict:
         url = self.api_urls.GET_MODEL_INPUT_FAST_TRACK
-        return self.get_model_input(url, site_design_configuration_id)
+        return self.get_request(url, str(site_design_configuration_id))
 
     def get_model_input_fast_track(self, site_design_configuration_id: int) -> dict:
         data = self.get_model_input_fast_track_json(site_design_configuration_id)
-        return self.json_response_to_df(data)
+        return json_response_to_df(data)
 
     def get_model_input_calibrate_fast_track_json(
         self, site_design_configuration_id: int
     ) -> dict:
         url = self.api_urls.GET_MODEL_INPUT_CALIBRATE_FAST_TRACK
-        return self.get_model_input(url, site_design_configuration_id)
+        return self.get_request(url, str(site_design_configuration_id))
 
     def get_model_input_calibrate_fast_track(
         self, site_design_configuration_id: int
@@ -66,13 +68,13 @@ class ScienceSdk:
         data = self.get_model_input_calibrate_fast_track_json(
             site_design_configuration_id
         )
-        return self.json_response_to_df(data)
+        return json_response_to_df(data)
 
     def get_model_input_density_analyses_fast_track_json(
         self, site_design_configuration_id: int
     ) -> dict:
         url = self.api_urls.GET_MODEL_INPUT_DENSITY_ANALYSES_FAST_TRACK
-        return self.get_model_input(url, site_design_configuration_id)
+        return self.get_request(url, str(site_design_configuration_id))
 
     def get_model_input_density_analyses_fast_track(
         self, site_design_configuration_id: int
@@ -80,14 +82,19 @@ class ScienceSdk:
         data = self.get_model_input_density_analyses_fast_track_json(
             site_design_configuration_id
         )
-        return self.json_response_to_df(data)
+        return json_response_to_df(data)
 
-    def json_response_to_df(self, data: dict) -> dict:
-        dfs = {}
-        for key, val in data.items():
-            dfs[key] = pd.json_normalize(val)
+    def get_planting_design_detail(
+            self, planting_design_id: int
+    ) -> dict:
+        url = self.api_urls.GET_PLANTING_DESIGN_DETAIL
+        return self.get_request(url, str(planting_design_id))
 
-        return dfs
+    def get_planting_design_list(
+            self
+    ) -> dict:
+        url = self.api_urls.GET_PLANTING_DESIGN_LIST
+        return self.get_request(url)
 
     # START LEGACY METHODS --------------------
     # TODO: remove once all fast track instances use new SDK methods
@@ -135,13 +142,16 @@ class ScienceSdk:
 
         return data.json()
 
-    def get_old_model_inputs(self, model_runs: list):
+    def get_old_model_inputs(self, model_runs: list, legacy_parameters=False):
         if not self.auth_token:
             raise ApiTokenError
 
         list_of_runs = ",".join(map(str, model_runs))
+        url = self.api_urls.GET_OLD_MODEL_INPUT_URL + f"={list_of_runs}",
+        if legacy_parameters:
+            url = url[0] + "&legacy_parameters"
         data = requests.get(
-            self.api_urls.GET_OLD_MODEL_INPUT_URL + f"={list_of_runs}",
+            url,
             headers={"Authorization": f"Bearer {self.auth_token}"},
         )
 
